/****************************************************************************
** Meta object code from reading C++ file 'quicksearchline.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../messagelib-26.07.90/messagelist/src/core/widgets/quicksearchline.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'quicksearchline.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11MessageList4Core15QuickSearchLineE_t {};
} // unnamed namespace

template <> constexpr inline auto MessageList::Core::QuickSearchLine::qt_create_metaobjectdata<qt_meta_tag_ZN11MessageList4Core15QuickSearchLineE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MessageList::Core::QuickSearchLine",
        "clearButtonClicked",
        "",
        "searchEditTextEdited",
        "searchOptionChanged",
        "statusButtonsClicked",
        "forceLostFocus",
        "saveFilter",
        "activateFilter",
        "MessageList::Core::Filter*",
        "f"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clearButtonClicked'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'searchEditTextEdited'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'searchOptionChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'statusButtonsClicked'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'forceLostFocus'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'saveFilter'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activateFilter'
        QtMocHelpers::SignalData<void(MessageList::Core::Filter *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QuickSearchLine, qt_meta_tag_ZN11MessageList4Core15QuickSearchLineE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MessageList::Core::QuickSearchLine::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MessageList4Core15QuickSearchLineE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MessageList4Core15QuickSearchLineE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11MessageList4Core15QuickSearchLineE_t>.metaTypes,
    nullptr
} };

void MessageList::Core::QuickSearchLine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QuickSearchLine *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clearButtonClicked(); break;
        case 1: _t->searchEditTextEdited((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->searchOptionChanged(); break;
        case 3: _t->statusButtonsClicked(); break;
        case 4: _t->forceLostFocus(); break;
        case 5: _t->saveFilter(); break;
        case 6: _t->activateFilter((*reinterpret_cast<std::add_pointer_t<MessageList::Core::Filter*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QuickSearchLine::*)()>(_a, &QuickSearchLine::clearButtonClicked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QuickSearchLine::*)(const QString & )>(_a, &QuickSearchLine::searchEditTextEdited, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QuickSearchLine::*)()>(_a, &QuickSearchLine::searchOptionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QuickSearchLine::*)()>(_a, &QuickSearchLine::statusButtonsClicked, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QuickSearchLine::*)()>(_a, &QuickSearchLine::forceLostFocus, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QuickSearchLine::*)()>(_a, &QuickSearchLine::saveFilter, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QuickSearchLine::*)(MessageList::Core::Filter * )>(_a, &QuickSearchLine::activateFilter, 6))
            return;
    }
}

const QMetaObject *MessageList::Core::QuickSearchLine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MessageList::Core::QuickSearchLine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MessageList4Core15QuickSearchLineE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int MessageList::Core::QuickSearchLine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void MessageList::Core::QuickSearchLine::clearButtonClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MessageList::Core::QuickSearchLine::searchEditTextEdited(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void MessageList::Core::QuickSearchLine::searchOptionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MessageList::Core::QuickSearchLine::statusButtonsClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MessageList::Core::QuickSearchLine::forceLostFocus()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MessageList::Core::QuickSearchLine::saveFilter()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void MessageList::Core::QuickSearchLine::activateFilter(MessageList::Core::Filter * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
